##  Example 2: How to Model Business Architecture with Value Streams and Processes (Manufacturing Company)
The example company is a traditional company from the manufacturing industry that focuses on improvements around business process efficiency, e.g., by Lean methodologies, which require understanding what to deliver to customers via value streams and how to deliver this (business processes).
In this scenario:
  1. The analysis of specific (business) value streams, for example, "Source to Pay," aims to understand how value is delivered to external or internal customers. Typically this involves modeling a sequence of high-level cross-functional (across different capabilities) activities and measuring key metrics at each step.
  2. The need to also model business processes (can also be the same value chain as value streams, e.g., Source to Pay), whereas in this case, the focus is more on the detailed step-by-step activities describing how it is undertaken. Measuring attributes such as Process Efficiency, Process Variance, and Level of Automation may all be interesting here.


Both 1. and 2. may also cater to different roles, e.g., enterprise architects may focus on value streams. In contrast, process owners, business analysts, and business architects may think more in terms of business processes. Integrating BPM solutions, e.g., SAP Signavio, makes sense for more advanced use cases.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2743fb457a4410149f66ebf85746afaa_LowRes.png)
